@@ -209,30 +209,48 @@ db_set_params (TrackerDBInterface *iface,
                gint                cache_size,
                gint                page_size)
 {
-	TrackerDBResultSet *result_set;
+	gchar *queries = NULL;
+	const gchar *pragmas_file;
 
-	tracker_db_interface_execute_query (iface, NULL, "PRAGMA synchronous = OFF;");
-	tracker_db_interface_execute_query (iface, NULL, "PRAGMA count_changes = 0;");
-	tracker_db_interface_execute_query (iface, NULL, "PRAGMA temp_store = FILE;");
-	tracker_db_interface_execute_query (iface, NULL, "PRAGMA encoding = \"UTF-8\"");
-	tracker_db_interface_execute_query (iface, NULL, "PRAGMA auto_vacuum = 0;");
+	pragmas_file = g_getenv ("TRACKER_PRAGMAS_FILE");
 
-	result_set = tracker_db_interface_execute_query (iface, NULL, "PRAGMA journal_mode = WAL;");
-	if (result_set == NULL) {
-		/* Don't just silence the problem. This pragma must return 'WAL' */
-		g_message ("Can't set journal mode to WAL");
+	if (pragmas_file && g_file_get_contents (pragmas_file, &queries, NULL, NULL)) {
+		g_debug ("PRAGMA's from file: %s", pragmas_file);
+		gchar *query = strtok (queries, "\n");
+		while (query) {
+			g_debug ("  INIT query: %s", query);
+			tracker_db_interface_execute_query (iface, NULL, query);
+			query = strtok (NULL, "\n");
+		}
+		g_free (queries);
 	} else {
-		g_object_unref (result_set);
+		GError *error = NULL;
+		TrackerDBResultSet *result_set;
+
+		tracker_db_interface_execute_query (iface, NULL, "PRAGMA synchronous = OFF;");
+		tracker_db_interface_execute_query (iface, NULL, "PRAGMA count_changes = 0;");
+		tracker_db_interface_execute_query (iface, NULL, "PRAGMA temp_store = FILE;");
+		tracker_db_interface_execute_query (iface, NULL, "PRAGMA encoding = \"UTF-8\"");
+		tracker_db_interface_execute_query (iface, NULL, "PRAGMA auto_vacuum = 0;");
+
+		result_set = tracker_db_interface_execute_query (iface, &error, "PRAGMA journal_mode = WAL;");
+		if (result_set == NULL) {
+			/* Don't just silence the problem. This pragma must return 'WAL' */
+			g_message ("Can't set journal mode to WAL: '%s'",
+			           error ? error->message : "unknown error");
+			g_clear_error (&error);
+		} else {
+			g_object_unref (result_set);
+		}
+
+		if (page_size != TRACKER_DB_PAGE_SIZE_DONT_SET) {
+			g_message ("  Setting page size to %d", page_size);
+			tracker_db_interface_execute_query (iface, NULL, "PRAGMA page_size = %d", page_size);
+		}
+
+		tracker_db_interface_execute_query (iface, NULL, "PRAGMA cache_size = %d", cache_size);
+		g_message ("  Setting cache size to %d", cache_size);
 	}
-
-	if (page_size != TRACKER_DB_PAGE_SIZE_DONT_SET) {
-		g_message ("  Setting page size to %d", page_size);
-		tracker_db_interface_execute_query (iface, NULL, "PRAGMA page_size = %d", page_size);
-	}
-
-	tracker_db_interface_execute_query (iface, NULL, "PRAGMA cache_size = %d", cache_size);
-	g_message ("  Setting cache size to %d", cache_size);
-
 }
 
 
@@ -358,7 +376,9 @@ db_manager_remove_journal (void)
 			}
 
 			fullpath = g_build_filename (dirs[i], f, NULL);
-			g_unlink (fullpath);
+			if (g_unlink (fullpath) == -1) {
+				g_message ("%s", g_strerror (errno));
+			}
 			g_free (fullpath);
 		}
 
@@ -369,7 +389,9 @@ db_manager_remove_journal (void)
 	g_free (directory);
 
 	/* Remove active journal */
-	g_unlink (path);
+	if (g_unlink (path) == -1) {
+		g_message ("%s", g_strerror (errno));
+	}
 	g_free (path);
 }
 
@@ -743,7 +765,7 @@ tracker_db_manager_init (TrackerDBManagerFlags  flags,
 	old_flags = flags;
 
 	filename = g_strdup_printf ("tracker-%s", g_get_user_name ());
-        g_free (sys_tmp_dir);
+	g_free (sys_tmp_dir);
 	sys_tmp_dir = g_build_filename (g_get_tmp_dir (), filename, NULL);
 	g_free (filename);
 
@@ -757,7 +779,7 @@ tracker_db_manager_init (TrackerDBManagerFlags  flags,
 		sql_dir = g_strdup (env_path);
 	}
 
-        g_free (user_data_dir);
+	g_free (user_data_dir);
 	user_data_dir = g_build_filename (g_get_user_data_dir (),
 	                                  "tracker",
 	                                  "data",
@@ -791,9 +813,6 @@ tracker_db_manager_init (TrackerDBManagerFlags  flags,
 	}
 
 	if (need_reindex) {
-		tracker_db_journal_init (NULL, FALSE);
-		db_manager_remove_journal ();
-		tracker_db_journal_shutdown ();
 		db_set_version ();
 	}
 
@@ -803,7 +822,7 @@ tracker_db_manager_init (TrackerDBManagerFlags  flags,
 		/* Fill absolute path for the database */
 		dir = location_to_directory (dbs[i].location);
 
-                g_free (dbs[i].abs_filename);
+		g_free (dbs[i].abs_filename);
 		dbs[i].abs_filename = g_build_filename (dir, dbs[i].file, NULL);
 
 		/* Check we have each database in place, if one is
@@ -1090,7 +1109,8 @@ void
 tracker_db_manager_move_to_temp (void)
 {
 	guint i;
-	gchar *cpath, *new_filename;
+	gchar *cpath, *filename;
+	gchar *fullpath;
 	gchar *directory, *rotate_to = NULL;
 	const gchar *dirs[3] = { NULL, NULL, NULL };
 	gsize chunk_size = 0;
@@ -1101,11 +1121,13 @@ tracker_db_manager_move_to_temp (void)
 	g_message ("Moving all database files");
 
 	for (i = 1; i < G_N_ELEMENTS (dbs); i++) {
-		new_filename = g_strdup_printf ("%s.tmp", dbs[i].abs_filename);
+		filename = g_strdup_printf ("%s.tmp", dbs[i].abs_filename);
 		g_message ("  Renaming database:'%s' -> '%s'",
-		           dbs[i].abs_filename, new_filename);
-		g_rename (dbs[i].abs_filename, new_filename);
-		g_free (new_filename);
+		           dbs[i].abs_filename, filename);
+		if (g_rename (dbs[i].abs_filename, filename) == -1) {
+			g_critical ("%s", g_strerror (errno));
+		}
+		g_free (filename);
 	}
 
 	cpath = g_strdup (tracker_db_journal_get_filename ());
@@ -1125,8 +1147,6 @@ tracker_db_manager_move_to_temp (void)
 		f_name = g_dir_read_name (journal_dir);
 
 		while (f_name) {
-			gchar *fullpath;
-
 			if (f_name) {
 				if (!g_str_has_prefix (f_name, TRACKER_DB_JOURNAL_FILENAME ".")) {
 					f_name = g_dir_read_name (journal_dir);
@@ -1135,9 +1155,11 @@ tracker_db_manager_move_to_temp (void)
 			}
 
 			fullpath = g_build_filename (dirs[i], f_name, NULL);
-			new_filename = g_strdup_printf ("%s.tmp", fullpath);
-			g_rename (fullpath, new_filename);
-			g_free (new_filename);
+			filename = g_strdup_printf ("%s.tmp", fullpath);
+			if (g_rename (fullpath, filename) == -1) {
+				g_critical ("%s", g_strerror (errno));
+			}
+			g_free (filename);
 			g_free (fullpath);
 			f_name = g_dir_read_name (journal_dir);
 		}
@@ -1145,15 +1167,25 @@ tracker_db_manager_move_to_temp (void)
 		g_dir_close (journal_dir);
 	}
 
+	fullpath = g_build_filename (directory, TRACKER_DB_JOURNAL_ONTOLOGY_FILENAME, NULL);
+	filename = g_strdup_printf ("%s.tmp", fullpath);
+	if (g_rename (fullpath, filename) == -1) {
+		g_critical ("%s", g_strerror (errno));
+	}
+	g_free (filename);
+	g_free (fullpath);
+
 	g_free (rotate_to);
 	g_free (directory);
 
-	new_filename = g_strdup_printf ("%s.tmp", cpath);
+	filename = g_strdup_printf ("%s.tmp", cpath);
 	g_message ("  Renaming journal:'%s' -> '%s'",
-	           cpath, new_filename);
-	g_rename (cpath, new_filename);
+	           cpath, filename);
+	if (g_rename (cpath, filename) == -1) {
+		g_critical ("%s", g_strerror (errno));
+	}
 	g_free (cpath);
-	g_free (new_filename);
+	g_free (filename);
 }
 
 
@@ -1161,7 +1193,8 @@ void
 tracker_db_manager_restore_from_temp (void)
 {
 	guint i;
-	gchar *cpath, *new_filename;
+	gchar *cpath, *filename;
+	gchar *fullpath;
 	gchar *directory, *rotate_to = NULL;
 	const gchar *dirs[3] = { NULL, NULL, NULL };
 	gsize chunk_size = 0;
@@ -1172,23 +1205,35 @@ tracker_db_manager_restore_from_temp (void)
 	g_message ("Moving all database files");
 
 	for (i = 1; i < G_N_ELEMENTS (dbs); i++) {
-		new_filename = g_strdup_printf ("%s.tmp", dbs[i].abs_filename);
+		filename = g_strdup_printf ("%s.tmp", dbs[i].abs_filename);
 		g_message ("  Renaming database:'%s' -> '%s'",
-		           dbs[i].abs_filename, new_filename);
-		g_rename (dbs[i].abs_filename, new_filename);
-		g_free (new_filename);
+		           dbs[i].abs_filename, filename);
+		if (g_rename (dbs[i].abs_filename, filename) == -1) {
+			g_critical ("%s", g_strerror (errno));
+		}
+		g_free (filename);
 	}
 
 	cpath = g_strdup (tracker_db_journal_get_filename ());
-	new_filename = g_strdup_printf ("%s.tmp", cpath);
+	filename = g_strdup_printf ("%s.tmp", cpath);
 	g_message ("  Renaming journal:'%s' -> '%s'",
-	           cpath, new_filename);
-	g_rename (cpath, new_filename);
-	g_free (new_filename);
+	           filename, cpath);
+	if (g_rename (filename, cpath) == -1) {
+		g_critical ("%s", g_strerror (errno));
+	}
+	g_free (filename);
 
 	directory = g_path_get_dirname (cpath);
 	tracker_db_journal_get_rotating (&do_rotate, &chunk_size, &rotate_to);
 
+	fullpath = g_build_filename (directory, TRACKER_DB_JOURNAL_ONTOLOGY_FILENAME, NULL);
+	filename = g_strdup_printf ("%s.tmp", fullpath);
+	if (g_rename (filename, fullpath) == -1) {
+		g_critical ("%s", g_strerror (errno));
+	}
+	g_free (filename);
+	g_free (fullpath);
+
 	dirs[0] = directory;
 	dirs[1] = do_rotate ? rotate_to : NULL;
 
@@ -1200,7 +1245,7 @@ tracker_db_manager_restore_from_temp (void)
 		f_name = g_dir_read_name (journal_dir);
 
 		while (f_name) {
-			gchar *fullpath, *ptr;
+			gchar *ptr;
 
 			if (f_name) {
 				if (!g_str_has_suffix (f_name, ".tmp")) {
@@ -1210,13 +1255,15 @@ tracker_db_manager_restore_from_temp (void)
 			}
 
 			fullpath = g_build_filename (dirs[i], f_name, NULL);
-			new_filename = g_strdup (fullpath);
-			ptr = strstr (new_filename, ".tmp");
+			filename = g_strdup (fullpath);
+			ptr = strstr (filename, ".tmp");
 			if (ptr) {
 				*ptr = '\0';
-				g_rename (fullpath, new_filename);
+				if (g_rename (fullpath, filename) == -1) {
+					g_critical ("%s", g_strerror (errno));
+				}
 			}
-			g_free (new_filename);
+			g_free (filename);
 			g_free (fullpath);
 			f_name = g_dir_read_name (journal_dir);
 		}
@@ -1232,7 +1279,7 @@ void
 tracker_db_manager_remove_temp (void)
 {
 	guint i;
-	gchar *cpath, *new_filename;
+	gchar *cpath, *filename;
 	gchar *directory, *rotate_to = NULL;
 	gsize chunk_size = 0;
 	gboolean do_rotate = FALSE;
@@ -1243,22 +1290,35 @@ tracker_db_manager_remove_temp (void)
 	g_message ("Removing all temp database files");
 
 	for (i = 1; i < G_N_ELEMENTS (dbs); i++) {
-		new_filename = g_strdup_printf ("%s.tmp", dbs[i].abs_filename);
+		filename = g_strdup_printf ("%s.tmp", dbs[i].abs_filename);
 		g_message ("  Removing temp database:'%s'",
-		           new_filename);
-		g_unlink (new_filename);
-		g_free (new_filename);
+		           filename);
+		if (g_unlink (filename) == -1) {
+			g_message ("%s", g_strerror (errno));
+		}
+		g_free (filename);
 	}
 
 	cpath = g_strdup (tracker_db_journal_get_filename ());
-	new_filename = g_strdup_printf ("%s.tmp", cpath);
+	filename = g_strdup_printf ("%s.tmp", cpath);
 	g_message ("  Removing temp journal:'%s'",
-	           new_filename);
-	g_unlink (new_filename);
-	g_free (new_filename);
+	           filename);
+	if (g_unlink (filename) == -1) {
+		g_message ("%s", g_strerror (errno));
+	}
+	g_free (filename);
 
 	directory = g_path_get_dirname (cpath);
 	tracker_db_journal_get_rotating (&do_rotate, &chunk_size, &rotate_to);
+	g_free (cpath);
+
+	cpath = g_build_filename (directory, TRACKER_DB_JOURNAL_ONTOLOGY_FILENAME, NULL);
+	filename = g_strdup_printf ("%s.tmp", cpath);
+	if (g_unlink (filename) == -1) {
+		g_message ("%s", g_strerror (errno));
+	}
+	g_free (filename);
+	g_free (cpath);
 
 	dirs[0] = directory;
 	dirs[1] = do_rotate ? rotate_to : NULL;
@@ -1278,9 +1338,11 @@ tracker_db_manager_remove_temp (void)
 				}
 			}
 
-			new_filename = g_build_filename (dirs[i], f_name, NULL);
-			g_unlink (new_filename);
-			g_free (new_filename);
+			filename = g_build_filename (dirs[i], f_name, NULL);
+			if (g_unlink (filename) == -1) {
+				g_message ("%s", g_strerror (errno));
+			}
+			g_free (filename);
 
 			f_name = g_dir_read_name (journal_dir);
 		}
@@ -1290,7 +1352,6 @@ tracker_db_manager_remove_temp (void)
 
 	g_free (rotate_to);
 	g_free (directory);
-	g_free (cpath);
 }
 
 void
