@@ -804,7 +804,7 @@ set_up_mount_point (TrackerMinerFiles *miner,
 	} else {
 		tracker_sparql_connection_update_async (tracker_miner_get_connection (TRACKER_MINER (miner)),
                                                         queries->str,
-                                                        G_PRIORITY_DEFAULT,
+                                                        G_PRIORITY_LOW,
                                                         NULL,
                                                         set_up_mount_point_cb,
                                                         g_strdup (removable_device_urn));
@@ -999,7 +999,7 @@ init_mount_points (TrackerMinerFiles *miner_files)
 	if (accumulator->str[0] != '\0') {
 		tracker_sparql_connection_update_async (tracker_miner_get_connection (miner),
                                                         accumulator->str,
-                                                        G_PRIORITY_DEFAULT,
+                                                        G_PRIORITY_LOW,
                                                         NULL,
                                                         init_mount_points_cb,
                                                         miner);
@@ -1164,7 +1164,7 @@ mount_point_added_cb (TrackerStorage *storage,
 	set_up_mount_point_type (miner, urn, removable, optical, queries);
 	tracker_sparql_connection_update_async (tracker_miner_get_connection (TRACKER_MINER (miner)),
                                                 queries->str,
-                                                G_PRIORITY_DEFAULT,
+                                                G_PRIORITY_LOW,
                                                 NULL,
                                                 set_up_mount_point_cb,
                                                 g_strdup (urn));
@@ -2719,7 +2719,7 @@ miner_files_in_removable_media_remove_by_type (TrackerMinerFiles  *miner,
 
 		tracker_sparql_connection_update_async (tracker_miner_get_connection (TRACKER_MINER (miner)),
                                                         queries->str,
-                                                        G_PRIORITY_DEFAULT,
+                                                        G_PRIORITY_LOW,
                                                         NULL,
                                                         remove_files_in_removable_media_cb,
                                                         NULL);
@@ -2761,7 +2761,7 @@ miner_files_in_removable_media_remove_by_date (TrackerMinerFiles  *miner,
 
 	tracker_sparql_connection_update_async (tracker_miner_get_connection (TRACKER_MINER (miner)),
                                                 queries->str,
-                                                G_PRIORITY_DEFAULT,
+                                                G_PRIORITY_LOW,
                                                 NULL,
                                                 remove_files_in_removable_media_cb,
                                                 NULL);
