@@ -430,8 +430,8 @@ albumart_heuristic (const gchar *artist,
 		/* Accept cover, front, folder, AlbumArt_{GUID}_Large
 		 * reject AlbumArt_{GUID}_Small and AlbumArtSmall
 		 */
-		if ((artist_strdown && strstr (name_strdown, artist_strdown)) ||
-		    (album_strdown && strstr (name_strdown, album_strdown)) ||
+		if ((artist_strdown && artist_strdown[0] != '\0' && strstr (name_strdown, artist_strdown)) ||
+		    (album_strdown && album_strdown[0] != '\0' && strstr (name_strdown, album_strdown)) ||
 		    (strstr (name_strdown, "cover")) ||
 		    (strstr (name_strdown, "front")) ||
 		    (strstr (name_strdown, "folder")) ||
@@ -461,10 +461,9 @@ albumart_heuristic (const gchar *artist,
 					found_file = g_file_new_for_path (found);
 					g_free (found);
 
-					g_file_copy (found_file, file, 0, NULL, NULL, NULL, &error);
+					retval = g_file_copy (found_file, file, 0, NULL, NULL, NULL, &error);
 					g_object_unref (found_file);
 
-					retval = error != NULL;
 					g_clear_error (&error);
 				}
 			} else if (g_str_has_suffix (name_strdown, "png")) {
